@@ -1,7 +1,8 @@
 """Top-level package for geodemo."""
 
 __author__ = """Qiusheng Wu"""
-__email__ = 'giswqs@gmail.com'
-__version__ = '0.0.4'
+__email__ = "giswqs@gmail.com"
+__version__ = '0.1.0'
 
 from .geodemo import *
+from .utils import *
